package com.agilecontrol.nea.core.tool;

import com.agilecontrol.nea.util.Configurations;
import com.agilecontrol.nea.util.FileUtils;
import java.io.File;
import java.io.FileInputStream;
import java.io.FilenameFilter;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

public class LogCheck {

   public static final String DEFAULT_PROPERTY_FILE = "/logcheck.properties";
   private static final String TABLE_EXTENSION = "sql.gz.out";
   private transient Logger logger = LoggerFactory.getLogger(LogCheck.class);
   Configurations conf;
   private String errDir = "/home/nds/var/errlog";
   private String checkDir = "/home/nds/posdb/tmp";
   private static final String LINE_SEPERATOR = System.getProperty("line.separator");


   public LogCheck() {
   }

   public LogCheck(Configurations conf) {
      this.conf = conf;
   }

   public void start() throws Exception {
      String directory = this.checkDir;
      File dir = new File(directory);
      LogCheck.FileSeacher filter = new LogCheck.FileSeacher(dir, "sql.gz.out");
      File[] files = dir.listFiles(filter);
      if(files != null && files.length != 0) {
         for(int i = 0; i < files.length; ++i) {
            try {
               this.checkLog(files[i]);
            } catch (Exception var7) {
               this.logger.error("Error found when init file:" + files[i], var7);
            }
         }

      } else {
         this.logger.debug("Could not find any tables in directory:" + dir);
      }
   }

   public void checkLog(File file) throws Exception {
      int filesize = (int)file.length();
      FileInputStream fis = new FileInputStream(file);
      byte[] data = new byte[filesize];
      fis.read(data);
      String content = new String(data);
      if(content.indexOf("ERROR ") > 0 || content.indexOf("ORA-") > 0) {
         this.logger.debug("Found file erro " + file.getName());
         FileUtils.copyFile(file, new File(this.errDir + "/" + file.getName()));
      }

   }

   private static void usage() {
      System.err.println("Usage:\n  java com.agilecontrol.nea.util.LogCheck [-p properties]");
      System.err.println("\nOptions:");
      System.err.println("  -p : indicates the property file");
   }

   public static void main(String[] argument) throws Exception {
      LogCheck m = null;

      try {
         String e = "/logcheck.properties";
         if(argument != null) {
            for(int is = 0; is < argument.length; ++is) {
               if(argument[is].equals("-p") && is + 1 < argument.length) {
                  e = argument[is + 1];
                  break;
               }
            }
         }

         System.setProperty("applicationPropertyFile", e);
         FileInputStream var6 = new FileInputStream(e);
         Configurations confs = new Configurations(var6);
         m = new LogCheck(confs);
      } catch (Exception var5) {
         var5.printStackTrace();
         usage();
         return;
      }

      m.start();
   }


   private class FileSeacher implements FilenameFilter {

      private File dir;
      private String ext;


      public FileSeacher(File dir, String extension) {
         this.dir = dir;
         this.ext = extension;
      }

      public boolean accept(File directory, String name) {
         return this.dir.equals(directory) && name.toLowerCase().endsWith(this.ext);
      }
   }
}
